@@ -11,15 +11,14 @@ from logilab.common.testlib import unittest_main
 from logilab.common.decorators import clear_cache
 from logilab.common.interface import implements
 
-from cubicweb.devtools.apptest import EnvBasedTC
+from cubicweb.devtools.testlib import CubicWebTC
 
 from cubicweb import ValidationError
 from cubicweb.interfaces import IMileStone, IWorkflowable
 from cubicweb.entities import AnyEntity
-from cubicweb.web.widgets import AutoCompletionWidget
 
 
-class BaseEntityTC(EnvBasedTC):
+class BaseEntityTC(CubicWebTC):
 
     def setup_database(self):
         self.member = self.create_user('member')
@@ -30,7 +29,7 @@ class MetadataTC(BaseEntityTC):
 
     def test_creator(self):
         self.login(u'member')
-        entity = self.add_entity('Bookmark', title=u"hello", path=u'project/cubicweb')
+        entity = self.request().create_entity('Bookmark', title=u"hello", path=u'project/cubicweb')
         self.commit()
         self.assertEquals(entity.creator.eid, self.member.eid)
         self.assertEquals(entity.dc_creator(), u'member')
@@ -100,7 +99,7 @@ class CWUserTC(BaseEntityTC):
                           )
 
 
-class InterfaceTC(EnvBasedTC):
+class InterfaceTC(CubicWebTC):
 
     def test_nonregr_subclasses_and_mixins_interfaces(self):
         CWUser = self.vreg['etypes'].etype_class('CWUser')
@@ -108,7 +107,7 @@ class InterfaceTC(EnvBasedTC):
         class MyUser(CWUser):
             __implements__ = (IMileStone,)
         self.vreg._loadedmods[__name__] = {}
-        self.vreg.register_appobject_class(MyUser)
+        self.vreg.register(MyUser)
         self.vreg['etypes'].initialization_completed()
         MyUser_ = self.vreg['etypes'].etype_class('CWUser')
         # a copy is done systematically
@@ -120,7 +119,7 @@ class InterfaceTC(EnvBasedTC):
         self.failIf(implements(MyUser, IWorkflowable))
 
 
-class SpecializedEntityClassesTC(EnvBasedTC):
+class SpecializedEntityClassesTC(CubicWebTC):
 
     def select_eclass(self, etype):
         # clear selector cache
@@ -137,8 +136,8 @@ class SpecializedEntityClassesTC(EnvBasedTC):
         self.vreg._loadedmods[__name__] = {}
         for etype in ('Company', 'Division', 'SubDivision'):
             class Foo(AnyEntity):
-                id = etype
-            self.vreg.register_appobject_class(Foo)
+                __regid__ = etype
+            self.vreg.register(Foo)
             eclass = self.select_eclass('SubDivision')
             self.failUnless(eclass.__autogenerated__)
             self.failIf(eclass is Foo)
@@ -148,7 +147,7 @@ class SpecializedEntityClassesTC(EnvBasedTC):
                 self.assertEquals(eclass.__bases__[0].__bases__, (Foo,))
         # check Division eclass is still selected for plain Division entities
         eclass = self.select_eclass('Division')
-        self.assertEquals(eclass.id, 'Division')
+        self.assertEquals(eclass.__regid__, 'Division')
 
 if __name__ == '__main__':
     unittest_main()
