@@ -147,7 +147,7 @@ winclude_directive.options = {'literal': directives.flag,
 
 try:
     from pygments import highlight
-    from pygments.lexers import get_lexer_by_name, LEXERS
+    from pygments.lexers import get_lexer_by_name
     from pygments.formatters import HtmlFormatter
 except ImportError:
     pygments_directive = None
