@@ -115,7 +115,7 @@ class GAEBasedTC(TestCase):
             for module in self.LOAD_APP_MODULES:
                 self.vreg.load_module(module)
         for cls in self.MODEL_CLASSES:
-            self.vreg.load_object(cls)
+            self.vreg.register(cls)
         self.session_manager = self.vreg.select('components', 'sessionmanager')
         if need_ds_init:
             # create default groups and create entities according to the schema
