@@ -9,7 +9,7 @@ __docformat__ = "restructuredtext en"
 _ = unicode
 
 from yams.buildobjs import (EntityType, RelationType, SubjectRelation,
-                            String, Boolean, Datetime, Password)
+                            String, Datetime, Password)
 from cubicweb.schema import (RQLConstraint, WorkflowableEntityType,
                              ERQLExpression, RRQLExpression)
 from cubicweb.schemas import META_ETYPE_PERMS, META_RTYPE_PERMS
@@ -170,19 +170,11 @@ class require_permission(RelationType):
     """link a permission to the entity. This permission should be used in the
     security definition of the entity's type to be useful.
     """
-    __permissions__ = {
-        'read':   ('managers', 'users', 'guests'),
-        'add':    ('managers',),
-        'delete': ('managers',),
-        }
+    __permissions__ = META_RTYPE_PERMS
 
 class require_group(RelationType):
     """used to grant a permission to a group"""
-    __permissions__ = {
-        'read':   ('managers', 'users', 'guests'),
-        'add':    ('managers',),
-        'delete': ('managers',),
-        }
+    __permissions__ = META_RTYPE_PERMS
 
 
 class ExternalUri(EntityType):
