@@ -291,7 +291,7 @@ class AbstractSource(object):
         """
         pass
 
-    def authenticate(self, session, login, password):
+    def authenticate(self, session, login, **kwargs):
         """if the source support CWUser entity type, it should implements
         this method which should return CWUser eid for the given login/password
         if this account is defined in this source and valid login / password is
