@@ -14,7 +14,7 @@ from urllib import unquote
 from logilab.common.testlib import TestCase, unittest_main
 from logilab.common.decorators import clear_cache
 
-from cubicweb.devtools.apptest import EnvBasedTC
+from cubicweb.devtools.testlib import CubicWebTC
 from cubicweb.devtools.fake import FakeRequest
 from cubicweb.web import Redirect, AuthenticationError, ExplicitLogin, INTERNAL_FIELD_VALUE
 from cubicweb.web.views.basecontrollers import ViewController
@@ -37,25 +37,25 @@ class MockCursor:
 class FakeController(ViewController):
 
     def __init__(self, form=None):
-        self.req = FakeRequest()
-        self.req.form = form or {}
-        self._cursor = self.req.cursor = MockCursor()
+        self._cw = FakeRequest()
+        self._cw.form = form or {}
+        self._cursor = self._cw.cursor = MockCursor()
 
     def new_cursor(self):
-        self._cursor = self.req.cursor = MockCursor()
+        self._cursor = self._cw.cursor = MockCursor()
 
     def set_form(self, form):
-        self.req.form = form
+        self._cw.form = form
 
 
 class RequestBaseTC(TestCase):
     def setUp(self):
-        self.req = FakeRequest()
+        self._cw = FakeRequest()
 
 
     def test_list_arg(self):
         """tests the list_arg() function"""
-        list_arg = self.req.list_form_param
+        list_arg = self._cw.list_form_param
         self.assertEquals(list_arg('arg3', {}), [])
         d = {'arg1' : "value1",
              'arg2' : ('foo', INTERNAL_FIELD_VALUE,),
@@ -69,8 +69,8 @@ class RequestBaseTC(TestCase):
 
 
     def test_from_controller(self):
-        self.req.vreg['controllers'] = {'view': 1, 'login': 1}
-        self.assertEquals(self.req.from_controller(), 'view')
+        self._cw.vreg['controllers'] = {'view': 1, 'login': 1}
+        self.assertEquals(self._cw.from_controller(), 'view')
         req = FakeRequest(url='project?vid=list')
         req.vreg['controllers'] = {'view': 1, 'login': 1}
         # this assertion is just to make sure that relative_path can be
@@ -123,7 +123,7 @@ class UtilsTC(TestCase):
 
 
         self.ctrl.new_cursor()
-        self.ctrl.req.form = {'__linkto' : 'works_for:12_13_14:object'}
+        self.ctrl._cw.form = {'__linkto' : 'works_for:12_13_14:object'}
         self.ctrl.execute_linkto(eid=8)
         self.assertEquals(self.ctrl._cursor.executed,
                           ['SET Y works_for X WHERE X eid 8, Y eid %s' % i
@@ -137,37 +137,13 @@ class UtilsTC(TestCase):
                            for i in (12, 13, 14)])
 
 
-class ApplicationTC(EnvBasedTC):
+class ApplicationTC(CubicWebTC):
     def setUp(self):
         super(ApplicationTC, self).setUp()
         def raise_hdlr(*args, **kwargs):
             raise
         self.app.error_handler = raise_hdlr
 
-    def publish(self, req, path='view'):
-        return self.app.publish(path, req)
-
-    def expect_redirect(self, callback, req):
-        try:
-            res = callback(req)
-            print res
-        except Redirect, ex:
-            try:
-                path, params = ex.location.split('?', 1)
-            except ValueError:
-                path = ex.location
-                params = {}
-            else:
-                cleanup = lambda p: (p[0], unquote(p[1]))
-                params = dict(cleanup(p.split('=', 1)) for p in params.split('&') if p)
-            path = path[len(req.base_url()):]
-            return path, params
-        else:
-            self.fail('expected a Redirect exception')
-
-    def expect_redirect_publish(self, req, path='view'):
-        return self.expect_redirect(lambda x: self.publish(x, path), req)
-
     def test_cnx_user_groups_sync(self):
         user = self.user()
         self.assertEquals(user.groups, set(('managers',)))
@@ -193,53 +169,52 @@ class ApplicationTC(EnvBasedTC):
     def test_publish_validation_error(self):
         req = self.request()
         user = self.user()
+        eid = unicode(user.eid)
         req.form = {
-            'eid':       `user.eid`,
-            '__type:'+`user.eid`:    'CWUser',
-            'login:'+`user.eid`:     '', # ERROR: no login specified
-            'edits-login:'+`user.eid`: unicode(user.login),
+            'eid':       eid,
+            '__type:'+eid:    'CWUser', '_cw_edited_fields:'+eid: 'login-subject',
+            'login-subject:'+eid:     '', # ERROR: no login specified
              # just a sample, missing some necessary information for real life
             '__errorurl': 'view?vid=edition...'
             }
-        path, params = self.expect_redirect_publish(req, 'edit')
+        path, params = self.expect_redirect(lambda x: self.app_publish(x, 'edit'), req)
         forminfo = req.get_session_data('view?vid=edition...')
         eidmap = forminfo['eidmap']
         self.assertEquals(eidmap, {})
         values = forminfo['values']
-        self.assertEquals(values['login:'+`user.eid`], '')
-        self.assertEquals(values['edits-login:'+`user.eid`], user.login)
-        self.assertEquals(values['eid'], `user.eid`)
-        errors = forminfo['errors']
-        self.assertEquals(errors.entity, user.eid)
-        self.assertEquals(errors.errors['login'], 'required attribute')
+        self.assertEquals(values['login-subject:'+eid], '')
+        self.assertEquals(values['eid'], eid)
+        error = forminfo['error']
+        self.assertEquals(error.entity, user.eid)
+        self.assertEquals(error.errors['login'], 'required attribute')
 
 
     def test_validation_error_dont_loose_subentity_data(self):
         """test creation of two linked entities
         """
         req = self.request()
-        form = {'eid': ['X', 'Y'],
-                '__type:X': 'CWUser',
+        form = {'eid': ['X', 'Y'], '__maineid': 'X',
+                '__type:X': 'CWUser', '_cw_edited_fields:X': 'login-subject,surname-subject',
                 # missing required field
-                'login:X': u'', 'edits-login:X': '',
-                'surname:X': u'Mr Ouaoua', 'edits-surname:X': '',
-                '__type:Y': 'EmailAddress',
+                'login-subject:X': u'',
+                'surname-subject:X': u'Mr Ouaoua',
                 # but email address is set
-                'address:Y': u'bougloup@logilab.fr', 'edits-address:Y': '',
-                'alias:Y': u'', 'edits-alias:Y': '',
-                'use_email:X': 'Y', 'edits-use_email:X': INTERNAL_FIELD_VALUE,
+                '__type:Y': 'EmailAddress', '_cw_edited_fields:Y': 'address-subject,alias-subject,use_email-object',
+                'address-subject:Y': u'bougloup@logilab.fr',
+                'alias-subject:Y': u'',
+                'use_email-object:Y': 'X',
                 # necessary to get validation error handling
                 '__errorurl': 'view?vid=edition...',
                 }
         req.form = form
         # monkey patch edited_eid to ensure both entities are edited, not only X
         req.edited_eids = lambda : ('Y', 'X')
-        path, params = self.expect_redirect_publish(req, 'edit')
+        path, params = self.expect_redirect(lambda x: self.app_publish(x, 'edit'), req)
         forminfo = req.get_session_data('view?vid=edition...')
-        self.assertUnorderedIterableEquals(forminfo['eidmap'].keys(), ['X', 'Y'])
-        self.assertEquals(forminfo['errors'].entity, forminfo['eidmap']['X'])
-        self.assertEquals(forminfo['errors'].errors, {'login': 'required attribute',
-                                                      'upassword': 'required attribute'})
+        self.assertEquals(set(forminfo['eidmap']), set('XY'))
+        self.assertEquals(forminfo['error'].entity, forminfo['eidmap']['X'])
+        self.assertEquals(forminfo['error'].errors, {'login': 'required attribute',
+                                                     'upassword': 'required attribute'})
         self.assertEquals(forminfo['values'], form)
 
     def _test_cleaned(self, kwargs, injected, cleaned):
@@ -286,63 +261,37 @@ class ApplicationTC(EnvBasedTC):
         req = self.request()
         origcnx = req.cnx
         req.form['__fblogin'] = u'turlututu'
-        page = self.publish(req)
+        page = self.app_publish(req)
         self.failIf(req.cnx is origcnx)
         self.assertEquals(req.user.login, 'turlututu')
         self.failUnless('turlututu' in page, page)
 
     # authentication tests ####################################################
 
-    def _init_auth(self, authmode, anonuser=None):
-        self.set_option('auth-mode', authmode)
-        self.set_option('anonymous-user', anonuser)
-        req = self.request()
-        origcnx = req.cnx
-        req.cnx = None
-        sh = self.app.session_handler
-        # not properly cleaned between tests
-        self.open_sessions = sh.session_manager._sessions = {}
-        return req, origcnx
-
-    def _test_auth_succeed(self, req, origcnx):
-        sh = self.app.session_handler
-        path, params = self.expect_redirect(lambda x: self.app.connect(x), req)
-        cnx = req.cnx
-        self.assertEquals(len(self.open_sessions), 1, self.open_sessions)
-        self.assertEquals(cnx.login, origcnx.login)
-        self.assertEquals(cnx.password, origcnx.password)
-        self.assertEquals(cnx.anonymous_connection, False)
-        self.assertEquals(path, 'view')
-        self.assertEquals(params, {'__message': 'welcome %s !' % cnx.user().login})
-
-    def _test_auth_fail(self, req):
-        self.assertRaises(AuthenticationError, self.app.connect, req)
-        self.assertEquals(req.cnx, None)
-        self.assertEquals(len(self.open_sessions), 0)
-        clear_cache(req, 'get_authorization')
-
     def test_http_auth_no_anon(self):
-        req, origcnx = self._init_auth('http')
-        self._test_auth_fail(req)
-        self.assertRaises(ExplicitLogin, self.publish, req, 'login')
+        req, origcnx = self.init_authentication('http')
+        self.assertAuthFailure(req)
+        self.assertRaises(ExplicitLogin, self.app_publish, req, 'login')
         self.assertEquals(req.cnx, None)
-        authstr = base64.encodestring('%s:%s' % (origcnx.login, origcnx.password))
+        authstr = base64.encodestring('%s:%s' % (origcnx.login, origcnx.authinfo['password']))
         req._headers['Authorization'] = 'basic %s' % authstr
-        self._test_auth_succeed(req, origcnx)
-        self.assertRaises(AuthenticationError, self.publish, req, 'logout')
+        self.assertAuthSuccess(req, origcnx)
+        self.assertEquals(req.cnx.authinfo, {'password': origcnx.authinfo['password']})
+        self.assertRaises(AuthenticationError, self.app_publish, req, 'logout')
         self.assertEquals(len(self.open_sessions), 0)
 
     def test_cookie_auth_no_anon(self):
-        req, origcnx = self._init_auth('cookie')
-        self._test_auth_fail(req)
-        form = self.publish(req, 'login')
+        req, origcnx = self.init_authentication('cookie')
+        self.assertAuthFailure(req)
+        form = self.app_publish(req, 'login')
         self.failUnless('__login' in form)
         self.failUnless('__password' in form)
         self.assertEquals(req.cnx, None)
         req.form['__login'] = origcnx.login
-        req.form['__password'] = origcnx.password
-        self._test_auth_succeed(req, origcnx)
-        self.assertRaises(AuthenticationError, self.publish, req, 'logout')
+        req.form['__password'] = origcnx.authinfo['password']
+        self.assertAuthSuccess(req, origcnx)
+        self.assertEquals(req.cnx.authinfo, {'password': origcnx.authinfo['password']})
+        self.assertRaises(AuthenticationError, self.app_publish, req, 'logout')
         self.assertEquals(len(self.open_sessions), 0)
 
     def test_login_by_email(self):
@@ -352,28 +301,20 @@ class ApplicationTC(EnvBasedTC):
                      'WHERE U login %(login)s', {'address': address, 'login': login})
         self.commit()
         # option allow-email-login not set
-        req, origcnx = self._init_auth('cookie')
+        req, origcnx = self.init_authentication('cookie')
         req.form['__login'] = address
-        req.form['__password'] = origcnx.password
-        self._test_auth_fail(req)
+        req.form['__password'] = origcnx.authinfo['password']
+        self.assertAuthFailure(req)
         # option allow-email-login set
         origcnx.login = address
         self.set_option('allow-email-login', True)
         req.form['__login'] = address
-        req.form['__password'] = origcnx.password
-        self._test_auth_succeed(req, origcnx)
-        self.assertRaises(AuthenticationError, self.publish, req, 'logout')
+        req.form['__password'] = origcnx.authinfo['password']
+        self.assertAuthSuccess(req, origcnx)
+        self.assertEquals(req.cnx.authinfo, {'password': origcnx.authinfo['password']})
+        self.assertRaises(AuthenticationError, self.app_publish, req, 'logout')
         self.assertEquals(len(self.open_sessions), 0)
 
-    def _test_auth_anon(self, req):
-        self.app.connect(req)
-        acnx = req.cnx
-        self.assertEquals(len(self.open_sessions), 1)
-        self.assertEquals(acnx.login, 'anon')
-        self.assertEquals(acnx.password, 'anon')
-        self.failUnless(acnx.anonymous_connection)
-        self._reset_cookie(req)
-
     def _reset_cookie(self, req):
         # preparing the suite of the test
         # set session id in cookie
@@ -384,6 +325,15 @@ class ApplicationTC(EnvBasedTC):
         # reset cnx as if it was a new incoming request
         req.cnx = None
 
+    def _test_auth_anon(self, req):
+        self.app.connect(req)
+        acnx = req.cnx
+        self.assertEquals(len(self.open_sessions), 1)
+        self.assertEquals(acnx.login, 'anon')
+        self.assertEquals(acnx.authinfo['password'], 'anon')
+        self.failUnless(acnx.anonymous_connection)
+        self._reset_cookie(req)
+
     def _test_anon_auth_fail(self, req):
         self.assertEquals(len(self.open_sessions), 1)
         self.app.connect(req)
@@ -393,34 +343,36 @@ class ApplicationTC(EnvBasedTC):
         self._reset_cookie(req)
 
     def test_http_auth_anon_allowed(self):
-        req, origcnx = self._init_auth('http', 'anon')
+        req, origcnx = self.init_authentication('http', 'anon')
         self._test_auth_anon(req)
         authstr = base64.encodestring('toto:pouet')
         req._headers['Authorization'] = 'basic %s' % authstr
         self._test_anon_auth_fail(req)
-        authstr = base64.encodestring('%s:%s' % (origcnx.login, origcnx.password))
+        authstr = base64.encodestring('%s:%s' % (origcnx.login, origcnx.authinfo['password']))
         req._headers['Authorization'] = 'basic %s' % authstr
-        self._test_auth_succeed(req, origcnx)
-        self.assertRaises(AuthenticationError, self.publish, req, 'logout')
+        self.assertAuthSuccess(req, origcnx)
+        self.assertEquals(req.cnx.authinfo, {'password': origcnx.authinfo['password']})
+        self.assertRaises(AuthenticationError, self.app_publish, req, 'logout')
         self.assertEquals(len(self.open_sessions), 0)
 
     def test_cookie_auth_anon_allowed(self):
-        req, origcnx = self._init_auth('cookie', 'anon')
+        req, origcnx = self.init_authentication('cookie', 'anon')
         self._test_auth_anon(req)
         req.form['__login'] = 'toto'
         req.form['__password'] = 'pouet'
         self._test_anon_auth_fail(req)
         req.form['__login'] = origcnx.login
-        req.form['__password'] = origcnx.password
-        self._test_auth_succeed(req, origcnx)
-        self.assertRaises(AuthenticationError, self.publish, req, 'logout')
+        req.form['__password'] = origcnx.authinfo['password']
+        self.assertAuthSuccess(req, origcnx)
+        self.assertEquals(req.cnx.authinfo, {'password': origcnx.authinfo['password']})
+        self.assertRaises(AuthenticationError, self.app_publish, req, 'logout')
         self.assertEquals(len(self.open_sessions), 0)
 
     def test_non_regr_optional_first_var(self):
         req = self.request()
         # expect a rset with None in [0][0]
         req.form['rql'] = 'rql:Any OV1, X WHERE X custom_workflow OV1?'
-        self.publish(req)
+        self.app_publish(req)
 
 if __name__ == '__main__':
     unittest_main()
