@@ -12,15 +12,15 @@ __docformat__ = "restructuredtext en"
 import re
 from urlparse import urljoin
 from urllib2 import urlopen, Request, HTTPError
+from urllib import quote as urlquote # XXX should use view.url_quote method
 
 from logilab.mtconverter import guess_encoding
 
-from cubicweb import urlquote # XXX should use view.url_quote method
 from cubicweb.selectors import (one_line_rset, score_entity,
                                 match_search_state, implements)
 from cubicweb.interfaces import IEmbedable
 from cubicweb.view import NOINDEX, NOFOLLOW
-from cubicweb.common.uilib import soup2xhtml
+from cubicweb.uilib import soup2xhtml
 from cubicweb.web.controller import Controller
 from cubicweb.web.action import Action
 from cubicweb.web.views import basetemplates
@@ -29,13 +29,13 @@ from cubicweb.web.views import basetemplates
 class ExternalTemplate(basetemplates.TheMainTemplate):
     """template embeding an external web pages into CubicWeb web interface
     """
-    id = 'external'
+    __regid__ = 'external'
 
     def call(self, body):
         # XXX fallback to HTML 4 mode when embeding ?
         self.set_request_content_type()
-        self.req.search_state = ('normal',)
-        self.template_header(self.content_type, None, self.req._('external page'),
+        self._cw.search_state = ('normal',)
+        self.template_header(self.content_type, None, self._cw._('external page'),
                              [NOINDEX, NOFOLLOW])
         self.content_header()
         self.w(body)
@@ -44,22 +44,22 @@ class ExternalTemplate(basetemplates.TheMainTemplate):
 
 
 class EmbedController(Controller):
-    id = 'embed'
+    __regid__ = 'embed'
     template = 'external'
 
     def publish(self, rset=None):
-        req = self.req
+        req = self._cw
         if 'custom_css' in req.form:
             req.add_css(req.form['custom_css'])
         embedded_url = req.form['url']
-        allowed = self.config['embed-allowed']
+        allowed = self._cw.vreg.config['embed-allowed']
         _ = req._
         if allowed is None or not allowed.match(embedded_url):
             body = '<h2>%s</h2><h3>%s</h3>' % (
                 _('error while embedding page'),
                 _('embedding this url is forbidden'))
         else:
-            prefix = req.build_url(self.id, url='')
+            prefix = req.build_url(self.__regid__, url='')
             authorization = req.get_header('Authorization')
             if authorization:
                 headers = {'Authorization' : authorization}
@@ -68,13 +68,13 @@ class EmbedController(Controller):
             try:
                 body = embed_external_page(embedded_url, prefix,
                                            headers, req.form.get('custom_css'))
-                body = soup2xhtml(body, self.req.encoding)
+                body = soup2xhtml(body, self._cw.encoding)
             except HTTPError, err:
                 body = '<h2>%s</h2><h3>%s</h3>' % (
                     _('error while embedding page'), err)
         self.process_rql(req.form.get('rql'))
-        return self.vreg['views'].main_template(req, self.template,
-                                                rset=self.rset, body=body)
+        return self._cw.vreg['views'].main_template(req, self.template,
+                                                rset=self.cw_rset, body=body)
 
 
 def entity_has_embedable_url(entity):
@@ -82,7 +82,7 @@ def entity_has_embedable_url(entity):
     url = entity.embeded_url()
     if not url or not url.strip():
         return 0
-    allowed = entity.config['embed-allowed']
+    allowed = entity._cw.vreg.config['embed-allowed']
     if allowed is None or not allowed.match(url):
         return 0
     return 1
@@ -92,20 +92,19 @@ class EmbedAction(Action):
     """display an 'embed' link on entity implementing `embeded_url` method
     if the returned url match embeding configuration
     """
-    id = 'embed'
+    __regid__ = 'embed'
     __select__ = (one_line_rset() & match_search_state('normal')
                   & implements(IEmbedable)
                   & score_entity(entity_has_embedable_url))
 
     title = _('embed')
-    controller = 'embed'
 
     def url(self, row=0):
-        entity = self.rset.get_entity(row, 0)
-        url = urljoin(self.req.base_url(), entity.embeded_url())
-        if self.req.form.has_key('rql'):
-            return self.build_url(url=url, rql=self.req.form['rql'])
-        return self.build_url(url=url)
+        entity = self.cw_rset.get_entity(row, 0)
+        url = urljoin(self._cw.base_url(), entity.embeded_url())
+        if self._cw.form.has_key('rql'):
+            return self._cw.build_url('embed', url=url, rql=self._cw.form['rql'])
+        return self._cw.build_url('embed', url=url)
 
 
 
