@@ -11,17 +11,17 @@ __docformat__ = "restructuredtext en"
 from cubicweb.view import StartupView
 
 class FourOhFour(StartupView):
-    id = '404'
+    __regid__ = '404'
 
     def call(self):
-        _ = self.req._
+        _ = self._cw._
         self.w(u"<h1>%s</h1>" % _('this resource does not exist'))
 
 
 class ErrorOccured(StartupView):
-    id = '500'
+    __regid__ = '500'
 
     def call(self):
-        _ = self.req._
+        _ = self._cw._
         self.w(u"<h1>%s</h1>" %
                _('an error occured, the request cannot be fulfilled'))
