@@ -8,6 +8,7 @@
 
 __docformat__ = "restructuredtext en"
 
+from logilab.common.deprecation import class_renamed
 from logilab.mtconverter import xml_escape
 
 from cubicweb import NoSelectableObject, role
@@ -47,7 +48,10 @@ class LazyViewMixin(object):
             tabid or vid, xml_escape(self._cw.build_url('json', **urlparams))))
         if show_spinbox:
             w(u'<img src="data/loading.gif" id="%s-hole" alt="%s"/>'
-              % (tabid or vid, self._cw._('loading')))
+              % (tabid or vid, self._cw._('(loading ...)')))
+        w(u'<noscript><p><a class="style: hidden" id="seo-%s" href="%s">%s</a></p></noscript>'
+          % (tabid or vid, xml_escape(self._cw.build_url(**urlparams)), xml_escape('%s (%s)') %
+             (tabid or vid, self._cw._('follow this link if javascript is deactivated'))))
         w(u'</div>')
         self._prepare_bindings(tabid or vid, reloadable)
 
@@ -187,11 +191,11 @@ class TabbedPrimaryView(TabsMixin, primary.PrimaryView):
 
     def cell_call(self, row, col):
         entity = self.cw_rset.complete_entity(row, col)
+        self.render_entity_toolbox(entity)
         self.render_entity_title(entity)
-        # XXX uncomment this in 3.6
-        #self.render_entity_toolbox(entity)
         self.render_tabs(self.tabs, self.default_tab, entity)
-TabedPrimaryView = TabbedPrimaryView # XXX deprecate that typo!
+
+TabedPrimaryView = class_renamed('TabedPrimaryView', TabbedPrimaryView)
 
 class PrimaryTab(primary.PrimaryView):
     __regid__ = 'main_tab'
