@@ -7,10 +7,10 @@
 """
 
 from logilab.mtconverter import xml_escape
+from logilab.common.date import date_range, todatetime
 
 from cubicweb.interfaces import ITimetableViews
 from cubicweb.selectors import implements
-from cubicweb.utils import date_range, todatetime
 from cubicweb.view import AnyRsetView
 
 
@@ -25,7 +25,7 @@ MIN_COLS = 3  # minimum number of task columns for a single user
 ALL_USERS = object()
 
 class TimeTableView(AnyRsetView):
-    id = 'timetable'
+    __regid__ = 'timetable'
     title = _('timetable')
     __select__ = implements(ITimetableViews)
     paginable = False
@@ -33,15 +33,15 @@ class TimeTableView(AnyRsetView):
     def call(self, title=None):
         """Dumps a timetable from a resultset composed of a note (anything
         with start/stop) and a user (anything)"""
-        self.req.add_css('cubicweb.timetable.css')
+        self._cw.add_css('cubicweb.timetable.css')
         dates = {}
         users = []
         users_max = {}
         # XXX: try refactoring with calendar.py:OneMonthCal
-        for row in xrange(self.rset.rowcount):
-            task = self.rset.get_entity(row, 0)
-            if len(self.rset[row]) > 1:
-                user = self.rset.get_entity(row, 1)
+        for row in xrange(self.cw_rset.rowcount):
+            task = self.cw_rset.get_entity(row, 0)
+            if len(self.cw_rset[row]) > 1:
+                user = self.cw_rset.get_entity(row, 1)
             else:
                 user = ALL_USERS
             the_dates = []
@@ -172,7 +172,7 @@ class TimeTableView(AnyRsetView):
             odd = not odd
 
             if not empty_line:
-                self.w(u'<th class="ttdate">%s</th>' % self.format_date(date) )
+                self.w(u'<th class="ttdate">%s</th>' % self._cw.format_date(date) )
             else:
                 self.w(u'<th>...</th>'  )
                 previous_is_empty = True
